#!/usr/bin/env python

import sys
import homewindow

from PyQt4.QtGui import QApplication

app = QApplication(sys.argv)
app.setOrganizationName("Stuart Howarth")
app.setOrganizationDomain("marxianthecoder.blogspot.com")
app.setApplicationName("FMRadio")
cuteTube = homewindow.HomeWindow()
app.exec_()
